package org.dromara.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.system.domain.SysUserTenant;
import org.dromara.system.domain.bo.SysUserTenantBo;
import org.dromara.system.domain.vo.SysUserTenantVo;
import org.dromara.system.mapper.SysUserTenantMapper;
import org.dromara.system.service.ISysUserTenantService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 用户账号-租户Service业务层处理
 *
 * @author boman
 * @date 2025-04-09
 */
@RequiredArgsConstructor
@Service
public class SysUserTenantServiceImpl implements ISysUserTenantService {

    private final SysUserTenantMapper baseMapper;

    /**
     * 查询用户账号-租户
     *
     * @param userId 主键
     * @return 用户账号-租户
     */
    @Override
    public SysUserTenantVo queryById(Long userId){
        return baseMapper.selectVoById(userId);
    }

    /**
     * 分页查询用户账号-租户列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 用户账号-租户分页列表
     */
    @Override
    public TableDataInfo<SysUserTenantVo> queryPageList(SysUserTenantBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<SysUserTenant> lqw = buildQueryWrapper(bo);
        Page<SysUserTenantVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的用户账号-租户列表
     *
     * @param bo 查询条件
     * @return 用户账号-租户列表
     */
    @Override
    public List<SysUserTenantVo> queryList(SysUserTenantBo bo) {
        LambdaQueryWrapper<SysUserTenant> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<SysUserTenant> buildQueryWrapper(SysUserTenantBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<SysUserTenant> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(SysUserTenant::getUserId);
        lqw.orderByAsc(SysUserTenant::getTenantId);
        return lqw;
    }

    /**
     * 新增用户账号-租户
     *
     * @param add 用户账号-租户
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(SysUserTenant add) {
        boolean flag = baseMapper.insert(add) > 0;
        return flag;
    }

    /**
     * 修改用户账号-租户
     *
     * @param bo 用户账号-租户
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(SysUserTenantBo bo) {
        SysUserTenant update = MapstructUtils.convert(bo, SysUserTenant.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(SysUserTenant entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除用户账号-租户信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
